# blueapps(蓝鲸开发框架)

## Installation

To install using `pip`:

```bash
$ pip install blueapps
```

__注__：blueapps `3.2.x` 版本推荐使用python `3.6.x` 环境，默认安装django版本为 `2.2.6` 。 blueapps `2.5.x` 版本对应的django版本为 `1.11.23`。

## Usage


### 生成开发框架
```bash
$ bk-admin init <app_code> [directory]
```

### 生成 Django APP
```bash
$ bk-admin startapp <app_name>
```


### 生成开发样例
```bash
$ bk-admin startexample
```

